@@ -46,13 +46,17 @@ class Model:
         self.view = None  # current view
         self.data = []  # list of data sets
         self.index = -1  # index of currently active data set
-        self.history = []  # command history
+        self.history = ["from copy import deepcopy",
+                        "import mne",
+                        "",
+                        "datasets = []"]
 
     @data_changed
     def insert_data(self, dataset):
         """Insert data set after current index."""
         self.index += 1
         self.data.insert(self.index, dataset)
+        self.history.append(f"datasets.insert({self.index}, data)")
 
     @data_changed
     def update_data(self, dataset):
@@ -74,6 +78,8 @@ class Model:
     def duplicate_data(self):
         """Duplicate current data set."""
         self.insert_data(deepcopy(self.current))
+        self.history[-1] = self.history[-1][:-5] + "deepcopy(data))"
+        self.history.append(f"data = datasets[{self.index}]")
         self.current["fname"] = None
         self.current["ftype"] = None
 
@@ -536,7 +542,9 @@ class Model:
     @data_changed
     def set_montage(self, montage):
         self.current["montage"] = montage
-        self.current["data"].set_montage(montage)
+        self.current["data"].set_montage(montage, raise_if_subset=False)
+        self.history.append(f"data.set_montage('{montage}', "
+                            f"raise_if_subset=False)")
 
     @data_changed
     def filter(self, low, high):
@@ -582,7 +590,8 @@ class Model:
         self.current["reference"] = ref
         if ref == "average":
             self.current["name"] += " (average ref)"
-            self.current["data"].set_eeg_reference(ref, projection=False)
+            self.current["data"].set_eeg_reference(ref)
+            self.history.append(f'data.set_eeg_reference("average")')
         else:
             self.current["name"] += " (" + ",".join(ref) + ")"
             if set(ref) - set(self.current["data"].info["ch_names"]):
@@ -593,9 +602,13 @@ class Model:
                 except RuntimeError:
                     raise AddReferenceError("Cannot add reference channels "
                                             "to average reference signals.")
+                else:
+                    self.history.append(f'mne.add_reference_channels(data, '
+                                        f'{ref}, copy=False)')
             else:
                 # re-reference to existing channel(s)
-                self.current["data"].set_eeg_reference(ref, projection=False)
+                self.current["data"].set_eeg_reference(ref)
+                self.history.append(f'data.set_eeg_reference({ref})')
 
     @data_changed
     def set_events(self, events):
